# OpenAIMessageType


## Enum

* `TEXT` (value: `'text'`)

* `IMAGE_URL` (value: `'image_url'`)

* `INPUT_AUDIO` (value: `'input_audio'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


